pub fn find_nearest_netelement(
point: &Point<f64>,
index: &NetworkIndex,
) -> Result<usize, ProjectionError>Expand description
Find the nearest netelement to a given point using R-tree spatial index
pub fn find_nearest_netelement(
point: &Point<f64>,
index: &NetworkIndex,
) -> Result<usize, ProjectionError>Find the nearest netelement to a given point using R-tree spatial index